summaryrefslogtreecommitdiffstats
path: root/kmail/headerstyle.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 20:02:55 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 21:02:00 +0200
commit533bad2a1503973aaf8186691422c2eda91d02d4 (patch)
treef7e52f62416048859aa9bde8425e20aac0e7c669 /kmail/headerstyle.cpp
parent8144d5434bbd1c4448a37695aed6ad3d348043d8 (diff)
downloadtdepim-533bad2a1503973aaf8186691422c2eda91d02d4.tar.gz
tdepim-533bad2a1503973aaf8186691422c2eda91d02d4.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'kmail/headerstyle.cpp')
-rw-r--r--kmail/headerstyle.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmail/headerstyle.cpp b/kmail/headerstyle.cpp
index 9e654d68..f7c2973e 100644
--- a/kmail/headerstyle.cpp
+++ b/kmail/headerstyle.cpp
@@ -276,14 +276,14 @@ namespace KMail {
#if 0
// Get Instant Messaging presence
TQString presence;
- TQString kabcUid;
+ TQString tdeabcUid;
if ( strategy->showHeader( "status" ) )
{
TDEABC::AddressBook *addressBook = TDEABC::StdAddressBook::self( true );
TDEABC::AddresseeList addresses = addressBook->findByEmail( KPIM::getFirstEmailAddress( message->from() ) );
::KIMProxy *imProxy = KMKernel::self()->imProxy();
- kabcUid = addresses[0].uid();
- presence = imProxy->presenceString( kabcUid );
+ tdeabcUid = addresses[0].uid();
+ presence = imProxy->presenceString( tdeabcUid );
}
#endif
@@ -298,7 +298,7 @@ namespace KMail {
"\">" + i18n("[vCard]") + "</a>" );
#if 0
if ( !presence.isEmpty() && strategy->showHeader( "status" ) )
- headerStr.append("&nbsp;&nbsp;(<span name=\"presence-" + kabcUid + "\">" + presence + "</span>)" );
+ headerStr.append("&nbsp;&nbsp;(<span name=\"presence-" + tdeabcUid + "\">" + presence + "</span>)" );
#endif
if ( strategy->showHeader( "organization" )
@@ -473,10 +473,10 @@ namespace KMail {
TQString userHTML;
TQString presence;
// IM presence and kabc photo
::KIMProxy *imProxy = KMKernel::self()->imProxy();
- TQString kabcUid;
+ TQString tdeabcUid;
TDEABC::AddressBook *addressBook = TDEABC::StdAddressBook::self( true );
TDEABC::AddresseeList addresses = addressBook->findByEmail( KPIM::getFirstEmailAddress( message->from() ) );
@@ -485,16 +485,16 @@ namespace KMail {
int photoHeight = 60;
if( addresses.count() == 1 )
{
- // kabcUid is embedded in im: URIs to indicate which IM contact to message
- kabcUid = addresses[0].uid();
+ // tdeabcUid is embedded in im: URIs to indicate which IM contact to message
+ tdeabcUid = addresses[0].uid();
if ( imProxy->initialize() ) {
// im status
- presence = imProxy->presenceString( kabcUid );
+ presence = imProxy->presenceString( tdeabcUid );
if ( !presence.isEmpty() )
{
TQString presenceIcon = TQString::fromLatin1( " <img src=\"%1\"/>" )
- .arg( imgToDataUrl( imProxy->presenceIcon( kabcUid ).convertToImage() ) );
+ .arg( imgToDataUrl( imProxy->presenceIcon( tdeabcUid ).convertToImage() ) );
presence += presenceIcon;
}
}
@@ -592,9 +592,9 @@ namespace KMail {
userHTML = TQString( "<div class=\"senderpic\">"
"<a href=\"im:%1\">%2<div class=\"senderstatus\">"
"<span name=\"presence-%3\">%4</span></div></a>"
- "</div>" ).arg( kabcUid )
+ "</div>" ).arg( tdeabcUid )
.arg( userHTML )
- .arg( kabcUid )
+ .arg( tdeabcUid )
.arg( presence );
}
} else {
@@ -602,8 +602,8 @@ namespace KMail {
if ( !presence.isEmpty() )
userHTML = TQString( "<a href=\"im:%1\"><div class=\"senderstatus\">"
"<span name=\"presence-%2\">%3</span></div></a>" )
- .arg( kabcUid )
- .arg( kabcUid )
+ .arg( tdeabcUid )
+ .arg( tdeabcUid )
.arg( presence );
}
#if 0
@@ -766,7 +766,7 @@ namespace KMail {
: TQString("") )
#if 0
+ ( ( !presence.isEmpty() )
- ? "&nbsp;&nbsp;(<span name=\"presence-" + kabcUid + "\">" + presence + "</span>)"
+ ? "&nbsp;&nbsp;(<span name=\"presence-" + tdeabcUid + "\">" + presence + "</span>)"
: TQString("") )
#endif
+ ( message->headerField("Organization").isEmpty()
@@ -473,10 +473,10 @@ namespace KMail {
TQString userHTML;
TQString presence;
- // IM presence and kabc photo
+ // IM presence and tdeabc photo
::KIMProxy *imProxy = KMKernel::self()->imProxy();